Install ViNorm package
```
pip install vinorm
```
Using in python script
```python
from vinorm import TTSnorm
S=TTSnorm("Hàm này được phát triển từ 8/2019, trả về định dạng là String đã được chuẩn hóa.")
```